@@ -3,8 +3,7 @@
 """
 This module implements the main Custodian class, which manages a list of jobs
 given a set of error handlers, the abstract base classes for the
-ErrorHandlers and Jobs, and some helper functions for backing up or
-compressing files in a directory.
+ErrorHandlers and Jobs.
 """
 
 from __future__ import division
@@ -17,6 +16,7 @@ __email__ = "shyuep@gmail.com"
 __date__ = "May 3, 2013"
 
 import logging
+import inspect
 import subprocess
 import datetime
 import time
@@ -24,10 +24,9 @@ import json
 from glob import glob
 import tarfile
 import os
-import tempfile
 import shutil
-from abc import ABCMeta, abstractmethod, abstractproperty
-from gzip import GzipFile
+from abc import ABCMeta, abstractmethod
+from .utils import ScratchDir, gzip_dir
 
 pjoin = os.path.join
 
@@ -80,53 +79,48 @@ class Custodian(object):
                  skip_over_errors=False, scratch_dir=None,
                  gzipped_output=False, checkpoint=False):
         """
+        Initializes a Custodian from a list of jobs and error handler.s
+
         Args:
-            handlers:
-                Error handlers. In order of priority of fixing.
-            jobs:
-                List of Jobs to be run sequentially.
-            max_errors:
-                Maximum number of errors allowed before exiting.
-            polling_time_step:
-                The length of time in seconds between steps in which a
-                job is checked for completion. Defaults to 10 seconds.
-            monitor_freq:
-                The number of polling steps before monitoring occurs. For
-                example, if you have a polling_time_step of 10seconds and a
-                monitor_freq of 30, this means that Custodian uses the
-                monitors to check for errors every 30 x 10 = 300 seconds,
+            handlers ([ErrorHandler]): Error handlers. In order of priority of
+                fixing.
+            jobs ([Job]): List of Jobs to be run sequentially.
+            max_errors (int): Maximum number of errors allowed before exiting.
+                Defaults to 1.
+            polling_time_step (int): The length of time in seconds between steps
+                in which a job is checked for completion. Defaults to 10 secs.
+            monitor_freq (int): The number of polling steps before monitoring
+                occurs. For example, if you have a polling_time_step of 10
+                seconds and a monitor_freq of 30, this means that Custodian uses
+                the monitors to check for errors every 30 x 10 = 300 seconds,
                 i.e., 5 minutes.
-            log_file:
-                Deprecated. Custodian now always logs to a custodian.json
-                file.
-            skip_over_errors:
-                If set to True, custodian will skip over error handlers that
-                failed (raised an Exception of some sort). Otherwise,
-                custodian will simply exit on unrecoverable errors.
+            log_file (str): Deprecated. Custodian now always logs to a
+                custodian.json file.
+            skip_over_errors (bool): If set to True, custodian will skip over
+                error handlers that failed (raised an Exception of some sort).
+                Otherwise, custodian will simply exit on unrecoverable errors.
                 The former will lead to potentially more robust performance,
                 but may make it difficult to improve handlers. The latter
                 will allow one to catch potentially bad error handler
                 implementations. Defaults to False.
-            scratch_dir:
-                If this is set, any files in the current directory are copied
-                to a temporary directory in a scratch space first before any
-                jobs are performed. This is useful in some setups where a
-                scratch partition has much faster IO. To use this, set
-                scratch_dir=root of directory you want to use for runs.
-                There is no need to provide unique directory names; we will
-                use python's tempfile creation mechanisms. A symbolic link
-                is created during the course of the run in the working
-                directory called "scratch_link" as users may want to
-                sometimes check the output during the course of a run. If
-                this is None (the default), the run is performed in the
-                current working directory.
-            gzipped_output:
-                Whether to gzip the final output to save space. Defaults to
-                False.
-            checkpoint:
-                Whether to checkpoint after each successful Job.
-                Checkpoints are stored as custodian.chk.#.tar.gz
-                files. Defaults to False.
+            scratch_dir (str): If this is set, any files in the current
+                directory are copied to a temporary directory in a scratch
+                space first before any jobs are performed, and moved back to
+                the current directory upon completion of all jobs. This is
+                useful in some setups where a scratch partition has much
+                faster IO. To use this, set scratch_dir=root of directory you
+                want to use for runs. There is no need to provide unique
+                directory names; we will use python's tempfile creation
+                mechanisms. A symbolic link is created during the course of
+                the run in the working directory called "scratch_link" as
+                users may want to sometimes check the output during the
+                course of a run. If this is None (the default), the run is
+                performed in the current working directory.
+            gzipped_output (bool): Whether to gzip the final output to save
+                space. Defaults to False.
+            checkpoint (bool):  Whether to checkpoint after each successful Job.
+                Checkpoints are stored as custodian.chk.#.tar.gz files. Defaults
+                to False.
         """
         self.max_errors = max_errors
         self.jobs = jobs
@@ -321,17 +315,62 @@ def _do_check(handlers, terminate_func=None, skip_over_errors=False):
     return corrections
 
 
-class ErrorHandler(object):
+class JSONSerializable(object):
+
+    @property
+    def to_dict(self):
+        d = {"@module": self.__class__.__module__,
+             "@class": self.__class__.__name__}
+        if hasattr(self, "__init__"):
+            for c in inspect.getargspec(self.__init__).args:
+                if c != "self":
+                    a = self.__getattribute__(c)
+                    if hasattr(a, "to_dict"):
+                        a = a.to_dict
+                    d[c] = a
+        return d
+
+    @classmethod
+    def from_dict(cls, d):
+        """
+        This method should return the ErrorHandler from a dict representation
+        of the object given by the to_dict property.
+        """
+        kwargs = {k: v for k, v in d.items()
+                  if k in inspect.getargspec(cls.__init__).args}
+        return cls(**kwargs)
+
+
+class ErrorHandler(JSONSerializable):
     """
     Abstract base class defining the interface for an ErrorHandler.
     """
     __metaclass__ = ABCMeta
 
+    """
+    This property indicates whether the error handler is a monitor,
+    i.e., a handler that monitors a job as it is running. If a
+    monitor-type handler notices an error, the job will be sent a
+    termination signal, the error is then corrected,
+    and then the job is restarted. This is useful for catching errors
+    that occur early in the run but do not cause immediate failure.
+    """
+    is_monitor = False
+
+    """
+    Whether this handler terminates a job upon error detection. Defaults
+    to True. Set to False for non-terminating errors, i.e., errors that
+    can be recovered from without terminating a job.
+    """
+    is_terminating = True
+
     @abstractmethod
     def check(self):
         """
-        This method is called at the end of a job. Returns a boolean value
-        indicating if errors are detected.
+        This method is called at the end of a job.
+
+        Returns:
+            (bool) Indicating if errors are detected.
         """
         pass
 
@@ -342,54 +381,16 @@ class ErrorHandler(object):
         It should perform any corrective measures relating to the detected
         error.
 
-        This method should return a JSON serializable dict that describes
-        the errors and actions taken. E.g.
-        {"errors": list_of_errors, "actions": list_of_actions_taken}.
-        If this is an unfixable error, actions should be set to None.
-        """
-        pass
-
-    @abstractproperty
-    def is_monitor(self):
-        """
-        This property indicates whether the error handler is a monitor,
-        i.e., a handler that monitors a job as it is running. If a
-        monitor-type handler notices an error, the job will be sent a
-        termination signal, the error is then corrected,
-        and then the job is restarted. This is useful for catching errors
-        that occur early in the run but do not cause immediate failure.
-        """
-        return False
-
-    @property
-    def is_terminating(self):
-        """
-        Whether this handler terminates a job upon error detection. Defaults
-        to True. Set to False for non-terminating errors, i.e., errors that
-        can be recovered from without terminating a job.
-        """
-        return True
-
-    @abstractproperty
-    def to_dict(self):
-        """
-        This method should return a JSON serializable dict describing the
-        ErrorHandler, and can be deserialized using the from_dict static
-        method.
-        """
-        pass
-
-    @classmethod
-    @abstractmethod
-    def from_dict(cls, d):
-        """
-        This method should return the ErrorHandler from a dict representation
-        of the object given by the to_dict property.
+        Returns:
+            (dict) JSON serializable dict that describes the errors and
+            actions taken. E.g.
+            {"errors": list_of_errors, "actions": list_of_actions_taken}.
+            If this is an unfixable error, actions should be set to None.
         """
         pass
 
 
-class Job(object):
+class Job(JSONSerializable):
     """
     Abstract base class defining the interface for a Job.
     """
@@ -420,130 +421,10 @@ class Job(object):
         """
         pass
 
-    @abstractproperty
+    @property
     def name(self):
         """
         A nice string name for the job.
         """
-        pass
+        return self.__class__.__name__
 
-    @abstractproperty
-    def to_dict(self):
-        """
-        This method should return a JSON serializable dict describing the
-        Job, and can be deserialized using the from_dict static
-        method.
-        """
-        pass
-
-    @classmethod
-    @abstractmethod
-    def from_dict(cls, d):
-        """
-        This method should return the Job from a dict representation of the
-        object given by the to_dict property.
-        """
-        pass
-
-
-def backup(filenames, prefix="error"):
-    """
-    Backup files to a tar.gz file. Used, for example, in backing up the
-    files of an errored run before performing corrections.
-
-    Args:
-        filenames:
-            List of files to backup. Supports wildcards, e.g., *.*.
-        prefix:
-            prefix to the files. Defaults to error, which means a series of
-            error.1.tar.gz, error.2.tar.gz, ... will be generated.
-    """
-    num = max([0] + [int(f.split(".")[1])
-                     for f in glob("{}.*.tar.gz".format(prefix))])
-    filename = "{}.{}.tar.gz".format(prefix, num + 1)
-    logging.info("Backing up run to {}.".format(filename))
-    with tarfile.open(filename, "w:gz") as tar:
-        for fname in filenames:
-            for f in glob(fname):
-                tar.add(f)
-
-
-def gzip_dir(path):
-    """
-    Gzips all files in a directory. Used, for instance, to compress all
-    files at the end of a run.
-
-    Args:
-        path:
-            Path to directory.
-    """
-    for f in os.listdir(path):
-        if not f.endswith("gz"):
-            with open(f, 'rb') as f_in, \
-                    GzipFile('{}.gz'.format(f), 'wb') as f_out:
-                f_out.writelines(f_in)
-            os.remove(f)
-
-
-def recursive_copy(src, dst):
-    """
-    Implements a recursive copy function similar to Unix's "cp -r" command.
-    Surprisingly, python does not have a real equivalent. shutil.copytree
-    only works if the destination directory is not present.
-
-    Args:
-        src:
-            Source folder to copy.
-        dst:
-            Destination folder.
-    """
-    for parent, subdir, files in os.walk(src):
-        parent = os.path.relpath(parent)
-        realdst = dst if parent == "." else os.path.join(dst, parent)
-        try:
-            os.makedirs(realdst)
-        except Exception as ex:
-            pass
-        for f in files:
-            shutil.copy(os.path.join(parent, f), realdst)
-
-
-class ScratchDir(object):
-    """
-    Creates a with context manager that automatically handles creation of
-    temporary directories in the scratch space and cleanup when done.
-    """
-
-    SCR_LINK = "scratch_link"
-
-    def __init__(self, rootpath):
-        """
-        Args:
-            rootpath:
-                The path in which to create temp subdirectories.
-        """
-        self.rootpath = rootpath
-        self.cwd = os.getcwd()
-
-    def __enter__(self):
-        tempdir = self.cwd
-        if self.rootpath is not None and os.path.abspath(self.rootpath) != \
-                self.cwd:
-            tempdir = tempfile.mkdtemp(dir=self.rootpath)
-            self.tempdir = os.path.abspath(tempdir)
-            recursive_copy(".", tempdir)
-            os.symlink(tempdir, ScratchDir.SCR_LINK)
-            os.chdir(tempdir)
-            logging.info(
-                "Using scratch directory {} and created symbolic "
-                "link called {} in working directory".format(
-                    tempdir, ScratchDir.SCR_LINK))
-        return tempdir
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        if self.rootpath is not None and os.path.abspath(self.rootpath) != \
-                self.cwd:
-            recursive_copy(".", self.cwd)
-            shutil.rmtree(self.tempdir)
-            os.chdir(self.cwd)
-            os.remove(ScratchDir.SCR_LINK)
\ No newline at end of file
