@@ -18,12 +18,11 @@ import subprocess
 import shutil
 
 from pymatgen.util.io_utils import zopen
-from pymatgen.serializers.json_coders import MSONable
 
 from custodian.custodian import Job, gzip_dir
 
 
-class NwchemJob(Job, MSONable):
+class NwchemJob(Job):
     """
     A basic Nwchem job.
     """
@@ -32,21 +31,20 @@ class NwchemJob(Job, MSONable):
                  output_file="mol.nwout", gzipped=False,
                  backup=True, settings_override=None):
         """
+        Initializes a basic NwChem job.
+
         Args:
-            nwchem_cmd:
-                Command to run Nwchem as a list of args. For example,
-                ["nwchem"].
-            output_file:
-                Name of file to direct standard out to.
-            backup:
-                Boolean whether to backup the initial input files. If True,
+            nwchem_cmd ([str]): Command to run Nwchem as a list of args. For
+                example, ["nwchem"].
+            input_file (str): Input file to run. Defaults to "mol.nw".
+            output_file (str): Name of file to direct standard out to.
+                Defaults to "mol.nwout".
+            backup (bool): Whether to backup the initial input files. If True,
                 the input files will be copied with a ".orig" appended.
                 Defaults to True.
-            gzipped:
-                Deprecated. Please use the Custodian class's gzipped_output
-                option instead. Whether to gzip the final output. Defaults to
-                False.
-            settings_override:
+            gzipped (bool): Deprecated. Please use the Custodian class's
+                gzipped_output option instead.
+            settings_override ([dict]):
                 An ansible style list of dict to override changes.
                 #TODO: Not implemented yet.
         """
@@ -58,36 +56,23 @@ class NwchemJob(Job, MSONable):
         self.settings_override = settings_override
 
     def setup(self):
+        """
+        Performs backup if necessary.
+        """
         if self.backup:
             shutil.copy(self.input_file, "{}.orig".format(self.input_file))
 
     def run(self):
+        """
+        Performs actual nwchem run.
+        """
         with zopen(self.output_file, 'w') as fout:
             return subprocess.Popen(self.nwchem_cmd + [self.input_file],
                                     stdout=fout)
 
     def postprocess(self):
+        """
+        Renaming or gzipping as needed.
+        """
         if self.gzipped:
             gzip_dir(".")
-
-    @property
-    def name(self):
-        return "Nwchem Job"
-
-    @property
-    def to_dict(self):
-        d = dict(nwchem_cmd=self.nwchem_cmd, input_file=self.input_file,
-                 output_file=self.output_file,
-                 gzipped=self.gzipped, backup=self.backup,
-                 settings_override=self.settings_override
-                 )
-        d["@module"] = self.__class__.__module__
-        d["@class"] = self.__class__.__name__
-        return d
-
-    @classmethod
-    def from_dict(cls, d):
-        return NwchemJob(
-            nwchem_cmd=d["nwchem_cmd"], input_file=d["input_file"],
-            output_file=d["output_file"], gzipped=d["gzipped"],
-            backup=d["backup"], settings_override=d["settings_override"])
